@@ -13,6 +13,8 @@
 #include <QRegularExpression>
 #include <QUrlQuery>
 
+using namespace std::chrono_literals;
+
 AlarmNotification::AlarmNotification(const QString &uid)
     : m_uid{uid}
 {
@@ -33,7 +35,6 @@ void AlarmNotification::send(KalendarAlarmClient *client, const KCalendarCore::I
     const bool notificationExists = m_notification;
     if (!notificationExists) {
         m_notification = new KNotification(QStringLiteral("alarm"));
-        m_notification->setFlags(KNotification::Persistent);
 
         // dismiss both with the explicit action and just closing the notification
         // there is no signal for explicit closing though, we only can observe that
@@ -41,18 +42,27 @@ void AlarmNotification::send(KalendarAlarmClient *client, const KCalendarCore::I
         QObject::connect(m_notification, &KNotification::closed, client, [this, client]() {
             client->dismiss(this);
         });
-        QObject::connect(m_notification, &KNotification::defaultActivated, client, [this, client, startTime]() {
-            client->showIncidence(uid(), startTime, m_notification->xdgActivationToken());
-        });
-        QObject::connect(m_notification, &KNotification::action1Activated, client, [this, client]() {
-            QObject::disconnect(m_notification, &KNotification::closed, client, nullptr);
-            client->suspend(this);
-        });
-        QObject::connect(m_notification, &KNotification::action2Activated, client, [this, client]() {
-            client->dismiss(this);
-        });
-        QObject::connect(m_notification, &KNotification::action3Activated, client, [this]() {
-            QDesktopServices::openUrl(m_contextAction);
+        QObject::connect(m_notification, &KNotification::activated, client, [this, client, startTime](unsigned int action) {
+            switch (action) {
+            case 0: // default
+                client->showIncidence(uid(), startTime, m_notification->xdgActivationToken());
+                break;
+            case 1: // suspend 5m
+                QObject::disconnect(m_notification, &KNotification::closed, client, nullptr);
+                client->suspend(this, 5min);
+                break;
+            case 2: // suspend 1h
+                QObject::disconnect(m_notification, &KNotification::closed, client, nullptr);
+                client->suspend(this, 1h);
+                break;
+            case 3: // dismiss
+                QObject::disconnect(m_notification, &KNotification::closed, client, nullptr);
+                client->dismiss(this);
+                break;
+            case 4: // openurl
+                QDesktopServices::openUrl(m_contextAction);
+                break;
+            }
         });
     }
 
@@ -61,26 +71,65 @@ void AlarmNotification::send(KalendarAlarmClient *client, const KCalendarCore::I
     m_notification->setText(m_text);
     m_notification->setDefaultAction(i18n("View"));
 
-    if (!m_text.isEmpty() && m_text != incidence->summary()) { // MS Teams sometimes repeats the summary as the alarm text, we don't need that
-        m_notification->setText(m_text);
-    } else if (incidence->type() == KCalendarCore::Incidence::TypeTodo && !incidence->dtStart().isValid()) {
+    QString text;
+    const auto now = QDateTime::currentDateTime();
+    const auto incidenceType = incidence->type() == KCalendarCore::Incidence::TypeTodo ? i18n("Task") : i18n("Event");
+    if (incidence->type() == KCalendarCore::Incidence::TypeTodo && !incidence->dtStart().isValid()) {
         const auto todo = incidence.staticCast<KCalendarCore::Todo>();
-        m_notification->setText(i18n("Task due at %1", QLocale().toString(todo->dtDue().time(), QLocale::NarrowFormat)));
+        text = i18n("Task due at %1", QLocale().toString(todo->dtDue().time(), QLocale::NarrowFormat));
     } else if (!incidence->allDay()) {
-        const QString incidenceType = incidence->type() == KCalendarCore::Incidence::TypeTodo ? i18n("Task") : i18n("Event");
-        const int startOffset = qRound(QDateTime::currentDateTime().secsTo(startTime) / 60.0);
+        const int startOffset = qRound(now.secsTo(startTime) / 60.0);
         if (startOffset > 0 && startOffset < 60) {
-            m_notification->setText(i18ncp("Event starts in 5 minutes", "%2 starts in %1 minute", "%2 starts in %1 minutes", startOffset, incidenceType));
+            text = i18ncp("Event starts in 5 minutes", "%2 starts in %1 minute", "%2 starts in %1 minutes", startOffset, incidenceType);
+        } else if (startTime.date() == now.date()) {
+            // event is/was today
+            if (startTime >= now) {
+                text = i18nc("Event starts at 10:00", "%1 starts at %2", incidenceType, QLocale().toString(startTime.time(), QLocale::NarrowFormat));
+            } else {
+                text = i18nc("Event started at 10:00", "%1 started at %2", incidenceType, QLocale().toString(startTime.time(), QLocale::NarrowFormat));
+            }
         } else {
-            m_notification->setText(
-                i18nc("Event starts at 10:00", "%1 starts at %2", incidenceType, QLocale().toString(startTime.time(), QLocale::NarrowFormat)));
+            // start time on a different day
+            if (startTime >= now) {
+                text = i18nc("Event starts on <DATE> at <TIME>",
+                             "%1 starts on %2 at %3",
+                             incidenceType,
+                             QLocale().toString(startTime.date(), QLocale::NarrowFormat),
+                             QLocale().toString(startTime.time(), QLocale::NarrowFormat));
+            } else {
+                text = i18nc("Event started on <DATE> at <TIME>",
+                             "%1 started on %2 at %3",
+                             incidenceType,
+                             QLocale().toString(startTime.date(), QLocale::NarrowFormat),
+                             QLocale().toString(startTime.time(), QLocale::NarrowFormat));
+            }
+        }
+    } else {
+        // all day events
+        if (startTime >= now) {
+            text = i18nc("Event starts on <DATE>", "%1 starts on %2", incidenceType, QLocale().toString(startTime.date(), QLocale::NarrowFormat));
+        } else {
+            text = i18nc("Event started on <DATE>", "%1 started on %2", incidenceType, QLocale().toString(startTime.date(), QLocale::NarrowFormat));
         }
     }
 
+    bool eventHasEnded = false;
+    if (incidence->type() == KCalendarCore::Incidence::TypeEvent) {
+        const auto event = incidence.staticCast<KCalendarCore::Event>();
+        const auto eventEndTime = startTime.addSecs(event->dtStart().secsTo(event->dtEnd()));
+        eventHasEnded = eventEndTime < QDateTime::currentDateTime();
+    }
+    m_notification->setFlags(eventHasEnded ? KNotification::CloseOnTimeout : KNotification::Persistent);
+
+    if (!m_text.isEmpty() && m_text != incidence->summary()) { // MS Teams sometimes repeats the summary as the alarm text, we don't need that
+        text = m_text + QLatin1Char('\n') + text;
+    }
+    m_notification->setText(text);
+
     m_notification->setIconName(incidence->type() == KCalendarCore::Incidence::TypeTodo ? QStringLiteral("view-task")
                                                                                         : QStringLiteral("view-calendar-upcoming"));
 
-    QStringList actions = {i18n("Remind in 5 mins"), i18n("Dismiss")};
+    QStringList actions = {i18n("Remind in 5 mins"), i18n("Remind in 1 hour"), i18nc("dismiss a reminder notification for an event", "Dismiss")};
     const auto contextAction = determineContextAction(incidence);
     if (!contextAction.isEmpty()) {
         actions.push_back(contextAction);
